@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Help;
 
-our $DATE = '2016-12-28'; # DATE
-our $VERSION = '0.13'; # VERSION
+our $DATE = '2017-01-27'; # DATE
+our $VERSION = '0.14'; # VERSION
 
 use 5.010001;
 use strict;
@@ -45,8 +45,13 @@ $SPEC{gen_help} = {
     },
 };
 sub gen_help {
+    no warnings 'once';
+    require Text::Wrap;
+
     my %args = @_;
 
+    local $Text::Wrap::columns = $ENV{COLUMNS} // 80;
+
     my $meta = $args{meta};
     my $common_opts = $args{common_opts} // {};
 
@@ -97,9 +102,6 @@ sub gen_help {
         push @help, "\nSubcommands:\n";
         if (keys(%$subcommands) >= 12) {
             # comma-separated list
-            no warnings 'once';
-            require Text::Wrap;
-            local $Text::Wrap::columns = $ENV{COLUMNS} // 80;
             push @help, Text::Wrap::wrap(
                 "  ", "  ", join(", ", sort keys %$subcommands)), "\n";
         } else {
@@ -185,11 +187,11 @@ sub gen_help {
 
                 my $add_sum = '';
                 if ($ospec->{is_base64}) {
-                    $add_sum = " (base64-encoded)";
+                    $add_sum = " (as base64-encoded str)";
                 } elsif ($ospec->{is_json}) {
-                    $add_sum = " (JSON-encoded)";
+                    $add_sum = " (as JSON-encoded str)";
                 } elsif ($ospec->{is_yaml}) {
-                    $add_sum = " (YAML-encoded)";
+                    $add_sum = " (as YAML-encoded str)";
                 }
 
                 my $argv = '';
@@ -210,7 +212,8 @@ sub gen_help {
                 push @help, sprintf(
                     "  %-${len}s  %s%s%s%s%s\n",
                     $opt,
-                    $ospec->{summary}//'',
+                    Text::Wrap::wrap("", " " x (2+$len+2 +2),
+                                     $ospec->{summary}//''),
                     $add_sum,
                     $argv,
                     $cmdline_src,
@@ -240,7 +243,7 @@ Perinci::CmdLine::Help - Generate help message for Perinci::CmdLine-based app
 
 =head1 VERSION
 
-This document describes version 0.13 of Perinci::CmdLine::Help (from Perl distribution Perinci-CmdLine-Help), released on 2016-12-28.
+This document describes version 0.14 of Perinci::CmdLine::Help (from Perl distribution Perinci-CmdLine-Help), released on 2017-01-27.
 
 =head1 DESCRIPTION
 
@@ -316,7 +319,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
